Returns the chart-relevant rows from the WCAG 2.1 audit: alt text, redundant group encoding, text contrast, text size, non-text contrast, hover/focus, and (at AAA) stronger text contrast.
Returns the chart-relevant rows from the WCAG 2.1 audit: alt text, redundant group encoding, text contrast, text size, non-text contrast, hover/focus, and (at AAA) stronger text contrast.