Returns the host-page rows from the WCAG 2.1 audit: heading hierarchy, text resizing, reflow, body text spacing, and visible keyboard focus.
Returns the host-page rows from the WCAG 2.1 audit: heading hierarchy, text resizing, reflow, body text spacing, and visible keyboard focus.