Returns a sentence counting how many checks need a decision, how many pass, and how many are already handled.
Arguments
- audit
Output of
a11y_audit(),a11y_audit_chart(), ora11y_audit_doc().
Returns a sentence counting how many checks need a decision, how many pass, and how many are already handled.
Output of a11y_audit(), a11y_audit_chart(), or a11y_audit_doc().